function _aws_cdk_aws_inspector_CfnAssessmentTargetProps(p) {
}
function _aws_cdk_aws_inspector_CfnResourceGroupProps(p) {
}
function _aws_cdk_aws_inspector_CfnAssessmentTemplateProps(p) {
}
function _aws_cdk_aws_inspector_CfnAssessmentTarget(p) {
}
function _aws_cdk_aws_inspector_CfnAssessmentTemplate(p) {
}
function _aws_cdk_aws_inspector_CfnResourceGroup(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_inspector_CfnAssessmentTargetProps, _aws_cdk_aws_inspector_CfnResourceGroupProps, _aws_cdk_aws_inspector_CfnAssessmentTemplateProps, _aws_cdk_aws_inspector_CfnAssessmentTarget, _aws_cdk_aws_inspector_CfnAssessmentTemplate, _aws_cdk_aws_inspector_CfnResourceGroup };
module.exports.DeprecationError = DeprecationError;
